import { Component, OnInit, ViewChild } from '@angular/core';
import { PageSettingsModel, QueryCellInfoEventArgs, SelectionSettingsModel, RowSelectEventArgs, RowDataBoundEventArgs } from '@syncfusion/ej2-grids';
import { PhysiotherapistService } from '@app/_services/physiotherapist.service';
import { ReportPain } from '@app/_models/ReportPain';
import { Exercise } from '@app/_models/exercise';
import { GridComponent } from '@syncfusion/ej2-angular-grids';


@Component({
  selector: 'app-sample-data-grid',
  templateUrl: './sample-data-grid.component.html',
  styleUrls: ['./sample-data-grid.component.scss']
})
export class SampleDataGridComponent implements OnInit {
  public datalocal: object[];
  public pageSettings: PageSettingsModel = { pageSize: 5 }
  public chartData: object[] = [];
  public selectionOptions: SelectionSettingsModel;
  public sortOptions: object;


  @ViewChild('grid', { static: false })
  public grid: GridComponent;


  constructor(private physiotherapistService: PhysiotherapistService) {

  }

  ngOnInit() {
    this.sortOptions = { columns: [{ field: 'name', direction: 'Ascending' }] };
    this.selectionOptions = { type: 'Single', mode: 'Row' };
    this.getData();
    this.datalocal = [
      {
        "id": 1,
        "name": "Fahrrad fahren",
        "arthroseGrad": 1,
        "mobilization": null,
        "strengthening": false,
        "coordination": true
      },
      {
        "id": 2,
        "name": "Kniebeuge",
        "arthroseGrad": 2,
        "mobilization": true,
        "strengthening": true,
        "coordination": true
      },
      {
        "id": 3,
        "name": "Glute Bridge",
        "arthroseGrad": 3,
        "mobilization": true,
        "strengthening": false,
        "coordination": true
      },
      {
        "id": 4,
        "name": "Seitlicher Unterstütz",
        "arthroseGrad": 3,
        "mobilization": true,
        "strengthening": true,
        "coordination": true
      },
      {
        "id": 5,
        "name": "Schere",
        "arthroseGrad": 4,
        "mobilization": true,
        "strengthening": false,
        "coordination": true
      },
      {
        "id": 6,
        "name": "Frosch",
        "arthroseGrad": 4,
        "mobilization": true,
        "strengthening": true,
        "coordination": true
      },
      {
        "id": 7,
        "name": "Seit-Hops",
        "arthroseGrad": 1,
        "mobilization": true,
        "strengthening": true,
        "coordination": true
      },
      {
        "id": 8,
        "name": "Hamstrings dehnen",
        "arthroseGrad": 2,
        "mobilization": true,
        "strengthening": true,
        "coordination": true
      }
    ];
  }

  getData(): void {
    this.physiotherapistService.GetExercises().subscribe(data => {
      this.chartData = data as Exercise[];
    });
  }

  rowSelected(args: RowSelectEventArgs) {
    let selectedrowindex: number[] = this.grid.getSelectedRowIndexes();  // Get the selected row indexes.
    console.log("selected row index: " + selectedrowindex);
    let selectedrecords: Object[] = this.grid.getSelectedRecords();  // Get the selected records.
    for (let entry of selectedrecords) {
      console.log(entry);
    }
  }
  rowDataBound(args: RowDataBoundEventArgs) {
    // args.row.classList.add('e-hover');
  }
  customiseCell(args: QueryCellInfoEventArgs) {
    if (args.column.field === 'arthroseGrad') {
      if (args.data['arthroseGrad'] === 1) {
        args.cell.classList.add('cellGreen');
      } else if (args.data['arthroseGrad'] === 2) {
        args.cell.classList.add('cellBlue');
      } else if (args.data['arthroseGrad'] === 3) {
        args.cell.classList.add('cellRed');
      } else if (args.data['arthroseGrad'] === 4) {
        args.cell.classList.add('cellPink');
      }
    }

    if (args.column.field === 'mobilization') {
      args.data = '<mat-icon>security</mat-icon>';
    }
  }


}
